aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/pluto/demux.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/pluto/demux.c b/src/pluto/demux.c
index 7e59b184d..8941c78c8 100644
--- a/src/pluto/demux.c
+++ b/src/pluto/demux.c
@@ -1197,12 +1197,12 @@ read_packet(struct msg_digest *md)
if ((pbs_room(&md->packet_pbs)==1) && (md->packet_pbs.start[0]==0xff))
{
/**
* NAT-T Keep-alive packets should be discared by kernel ESPinUDP
* layer. But boggus keep-alive packets (sent with a non-esp marker)
* can reach this point. Complain and discard them.
*/
DBG(DBG_NATT,
- DBG_log("NAT-T keep-alive (boggus ?) should not reach this point. "
+ DBG_log("NAT-T keep-alive (bogus ?) should not reach this point. "
"Ignored. Sender: %s:%u", ip_str(cur_from),
(unsigned) cur_from_port);
)
@@ -1197,12 +1197,12 @@ read_packet(struct msg_digest *md)
{
/**
- * NAT-T Keep-alive packets should be discared by kernel ESPinUDP
- * layer. But boggus keep-alive packets (sent with a non-esp marker)
+ * NAT-T Keep-alive packets should be discarded by kernel ESPinUDP
+ * layer. But bogus keep-alive packets (sent with a non-esp marker)
* can reach this point. Complain and discard them.
*/